function BuildGui()
local frame = StrudelStoreGui:Create("ResizableFrame");
frame:SetTitle("StrudelStore");
frame:SetStatusText("v".. GetAddOnMetadata("StrudelStore", "Version"));
frame:SetPoint("CENTER", "UIParent", "CENTER", 0, 0);
frame:SetCallback("OnClose", function(widget) StrudelStoreGui:Release(widget); end);
-- Fill Layout - the TabGroup widget will fill the whole frame
frame:SetLayout("Fill");
frame:SetWidth(390);
frame:SetHeight(200);
-- Create the TabGroup
local tab =  StrudelStoreGui:Create("TabGroup");
tab:SetLayout("Flow")
tab:SetTabs(FilterTabs());
-- Register callback
tab:SetCallback("OnGroupSelected",SelectGroup);
-- Set initial Tab (this will fire the OnGroupSelected callback)
tab:SelectTab("tab1");
-- add to the frame container
frame:AddChild(tab);
return frame;
end

--Show/Hide the main window
function ToggleMainWindow()
if StrudelStoreMain.mainframe:IsVisible() then
StrudelStoreGui:Release(StrudelStoreMain.mainframe);
else
if not UnitAffectingCombat("player") then
StrudelStoreMain.mainframe = BuildGui();
else
local L = LibStub("AceLocale-3.0"):GetLocale("StrudelStore", true);
StrudelStoreConsole:Print(L["CombatError"]);
end
end
end

-- function that draws the widgets for the conjure
function DrawConjure(container)
  local buttons = GetConjureButtons();
	for i = 1,table.getn(buttons), 1 do
		container:AddChild(buttons[i]);
	end
end

-- function that draws the widgets for the portal tab
function DrawPortal(container)
	local buttons = GetPortalButtons();
	for i = 1,table.getn(buttons), 1 do
		container:AddChild(buttons[i]);
	end
end

-- function that draws the widgets for the teleport tab
function DrawTeleport(container)
	local buttons = GetTeleportButtons();
	for i = 1,table.getn(buttons), 1 do
		container:AddChild(buttons[i]);
	end
end

-- Callback function for OnGroupSelected
function SelectGroup(_widget, event, group)
   _widget:ReleaseChildren();
   if group == "tab1" then
      DrawConjure(_widget);
   elseif group == "tab2" then
      DrawPortal(_widget);
	elseif group == "tab3" then
	  DrawTeleport(_widget);
   end
end

function FilterTabs()
-- Setup which tabs to show
local L = LibStub("AceLocale-3.0"):GetLocale("StrudelStore", true);
local tablist = {};
if StrudelStoreMain.db.char.showportaltab and
   StrudelStoreMain.db.char.showteleporttab then
   tablist = {{text=L["ConjureTabButton"], value="tab1"}, {text=L["PortalTabButton"], value="tab2"},{text=L["TeleportTabButton"], value="tab3"}}

elseif StrudelStoreMain.db.char.showportaltab and
		not StrudelStoreMain.db.char.showteleporttab then
	tablist = {{text=L["ConjureTabButton"], value="tab1"}, {text=L["PortalTabButton"], value="tab2"}}	
	
elseif not StrudelStoreMain.db.char.showportaltab and
StrudelStoreMain.db.char.showteleporttab then
	tablist = {{text=L["ConjureTabButton"], value="tab1"},{text=L["TeleportTabButton"], value="tab3"}}
	
elseif not StrudelStoreMain.db.char.showportaltab and
not StrudelStoreMain.db.char.showteleporttab then
	tablist = {{text=L["ConjureTabButton"], value="tab1"}}
end
return tablist;
end